name property
The friendly name or description for the Rule. You can't change
the name of a Rule after you create it.
Implementation
final String? name;
The friendly name or description for the Rule. You can't change
the name of a Rule after you create it.
final String? name;